#ifndef NT2_INCLUDE_FUNCTIONS_FAST_LDEXP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FAST_LDEXP_HPP_INCLUDED

#include <nt2/ieee/include/functions/fast_ldexp.hpp>

#endif
